==> kzFauxTexte-1_0_0.zip: kzFauxTexte/admin.php <==
<?php

plxToken::validateFormToken();

if(filter_has_var(INPUT_POST, 'ebook')) {
	$params = filter_input_array(INPUT_POST, array(
		'ebook'			=> FILTER_SANITIZE_STRING,
		'paragraphs'	=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_PARAS, 'max_range' => kzFauxTexte::MAX_PARAS)
        ),
		'minsize'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_SIZE, 'max_range' => kzFauxTexte::MAX_SIZE)
        ),
		'maxsize'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_SIZE, 'max_range' => kzFauxTexte::MAX_SIZE)
        ),
		'articles'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_ARTS, 'max_range' => kzFauxTexte::MAX_ARTS)
        ),
		'author'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{3}$@')
		),
		'categorie'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{3}$@')
		),
		'thumb'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^(0|1)$@')
		),
		'medias'		=> FILTER_SANITIZE_STRING,
		'begin'			=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{4}-\d{2}-\d{2}$@')
		),
		'replace_all'	=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^(0|1)$@')
		),
	));

	foreach($plxPlugin->default_values as $key=>$default) {
		if(empty($params[$key])) { $params[$key] = $default; }
		$plxPlugin->setParam($key, $params[$key], 'string');
	}

	// Ces champs doivent avoir une valeur multiple de kzFauxTexte::STEP_SIZE
	foreach(array('minsize', 'maxsize') as $k) {
		if($params[$k] % kzFauxTexte::STEP_SIZE != 0) {
			$params[$k] = intval(round($params[$k] / kzFauxTexte::STEP_SIZE)) * kzFauxTexte::STEP_SIZE;
		}
	}
	if($params['maxsize'] < $params['minsize']) {
		$params['maxsize'] = $params['minsize'];
	}
	$plxPlugin->saveParams();
	$plxPlugin->createArticles();
	header('Location: plugin.php?p=' . $plugin);
	exit;
}

$yes_no = array('0' => L_NO, '1' =>  L_YES);
?>
<div class="banner">
	<?php $plxPlugin->lang('BANNER'); ?>
</div>
<form id="<?= $plugin ?>" method="post">
	<div class="in-action-bar">
		<?= plxToken::getTokenPostMethod() ?>
		<input type="submit" value="<?= $plxPlugin->getLang('GENERATE'); ?>" />
		<div class="sliding-text">
			<div><?= $plxPlugin->getLang('PROCESS_RUNNING') ?> ...</div>
		</div>
	</div>
<?php
foreach(array_keys($plxPlugin->default_values) as $input) {
	$value = $plxPlugin->getParam($input);
	if(empty($value)) { $value = $plxPlugin->default_values[$input]; }
?>
	<div>
		<label for="id_<?= $input ?>"><?= $plxPlugin->getLang(strtoupper($input)) ?></label>
<?php
	switch($input) {
		case 'ebook'		: plxUtils::printSelect($input, $plxPlugin->getEbooks(), $value); break;
		case 'paragraphs'	: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_PARAS . '" max="' . kzFauxTexte::MAX_PARAS . '"'); break;
		case 'minsize'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_SIZE .'" max="' . kzFauxTexte::MAX_SIZE .'" step="' . kzFauxTexte::STEP_SIZE .'"'); break;
		case 'maxsize'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_SIZE .'" max="' . kzFauxTexte::MAX_SIZE .'" step="' . kzFauxTexte::STEP_SIZE .'"'); break;
		case 'articles'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_ARTS . '" max="' . kzFauxTexte::MAX_ARTS . '"'); break;
		case 'author'		: plxUtils::printSelect($input, $plxPlugin->getAuthors(), $value); break;
		case 'categorie'	: plxUtils::printSelect($input, $plxPlugin->getCategories(), $value); break;
		case 'medias'		: plxUtils::printSelect($input, $plxPlugin->getMedias(), $value); break;
		case 'template'		: plxUtils::printSelect($input, $plxPlugin->getTemplates(), $value); break;
		case 'begin'		: plxUtils::printInput($input, $value, 'date'); break;
		case 'thumb'		: plxUtils::printSelect($input, $yes_no, $value); break;
		case 'replace_all'	: plxUtils::printSelect($input, $yes_no, $value); break;
	}
	if(substr($input, -4) == 'size') {
?>
 <em><?php printf($plxPlugin->getLang('MIN_MAX_SIZE'), kzFauxTexte::STEP_SIZE, kzFauxTexte::MIN_SIZE, kzFauxTexte::MAX_SIZE); ?></em>
<?php
	}
?>
	</div>
<?php
}
?>
</form>
<div>
	<h3>Bibliothèques numériques :</h3>
	<ul>
		<li><a href="https://bibliothequenumerique.tv5monde.com/livres" target="_blank">TV5 Monde</a></li>
		<li><a href="https://ebooks-bnr.com/" target="_blank">Bibliothèque Numérique Romande</a></li>
		<li><a href="http://fr.feedbooks.com/publicdomain" target="_blank">FeedBooks</a></li>
		<li><a href="https://www.ebooksgratuits.com/ebooks.php" target="_blank">EbooksGratuit</a></li>
		<li><a href="http://www.efele.net/ebooks/i" target="_blank">Efele</a></li>
	</ul>
	<h3>Quelques livres recommandés :</h3>
	<ul>
		<li><a href="https://fr.feedbooks.com/book/55.epub" download>Le tour du Monde en 80 jours - Jules Verne</a></li>
		<li><a href="https://ebooks-bnr.com/ebooks/epub/pergaud_vie_betes_psycho_animale.epub" download>La vie des bêtes - Louis Pergaud</a></li>
		<li><a href="https://bibliothequenumerique.tv5monde.com/livre/201/Nana" download>Nana - Emile Zola</a></li>
	</ul>
</div>
<script>
(function() {
	document.getElementById('<?= $plugin ?>').addEventListener('submit', function(event) {
		if(parseInt(event.target.elements.minsize.value) >= parseInt(event.target.elements.maxsize.value)) {
			event.preventDefault();
			event.target.elements.minsize.focus();
			alert("<?= $plxPlugin->getLang('WARN_PARAGRAPH_LIMITS') ?>");
		} else {
			event.target.classList.add('spinner');
		}
	})
})();
</script>

==> kzFauxTexte-1_0_1.zip: kzFauxTexte/admin.php <==
<?php

plxToken::validateFormToken();

if(filter_has_var(INPUT_POST, 'ebook')) {
	$params = filter_input_array(INPUT_POST, array(
		'ebook'			=> FILTER_SANITIZE_SPECIAL_CHARS,
		'paragraphs'	=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_PARAS, 'max_range' => kzFauxTexte::MAX_PARAS)
        ),
		'minsize'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_SIZE, 'max_range' => kzFauxTexte::MAX_SIZE)
        ),
		'maxsize'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_SIZE, 'max_range' => kzFauxTexte::MAX_SIZE)
        ),
		'articles'		=> array(
			'filter'    => FILTER_VALIDATE_INT,
			'options'   => array('min_range' => kzFauxTexte::MIN_ARTS, 'max_range' => kzFauxTexte::MAX_ARTS)
        ),
		'author'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{3}$@')
		),
		'categorie'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{3}$@')
		),
		'thumb'		=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^(0|1)$@')
		),
		'medias'		=> FILTER_SANITIZE_SPECIAL_CHARS,
		'begin'			=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^\d{4}-\d{2}-\d{2}$@')
		),
		'replace_all'	=> array(
			'filter'	=> FILTER_VALIDATE_REGEXP,
			'options'	=> array('regexp' => '@^(0|1)$@')
		),
	));

	foreach($plxPlugin->default_values as $key=>$default) {
		if(empty($params[$key])) { $params[$key] = $default; }
		$plxPlugin->setParam($key, $params[$key], 'string');
	}

	// Ces champs doivent avoir une valeur multiple de kzFauxTexte::STEP_SIZE
	foreach(array('minsize', 'maxsize') as $k) {
		if($params[$k] % kzFauxTexte::STEP_SIZE != 0) {
			$params[$k] = intval(round($params[$k] / kzFauxTexte::STEP_SIZE)) * kzFauxTexte::STEP_SIZE;
		}
	}
	if($params['maxsize'] < $params['minsize']) {
		$params['maxsize'] = $params['minsize'];
	}
	$plxPlugin->saveParams();
	$plxPlugin->createArticles();
	header('Location: plugin.php?p=' . $plugin);
	exit;
}

$yes_no = array('0' => L_NO, '1' =>  L_YES);
?>
<div class="banner">
	<?php $plxPlugin->lang('BANNER'); ?>
</div>
<form id="<?= $plugin ?>" method="post">
	<div class="in-action-bar">
		<?= plxToken::getTokenPostMethod() ?>
		<input type="submit" value="<?= $plxPlugin->getLang('GENERATE'); ?>" />
		<div class="sliding-text">
			<div><?= $plxPlugin->getLang('PROCESS_RUNNING') ?> ...</div>
		</div>
	</div>
<?php
foreach(array_keys($plxPlugin->default_values) as $input) {
	$value = $plxPlugin->getParam($input);
	if(empty($value)) { $value = $plxPlugin->default_values[$input]; }
?>
	<div>
		<label for="id_<?= $input ?>"><?= $plxPlugin->getLang(strtoupper($input)) ?></label>
<?php
	switch($input) {
		case 'ebook'		: plxUtils::printSelect($input, $plxPlugin->getEbooks(), $value); break;
		case 'paragraphs'	: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_PARAS . '" max="' . kzFauxTexte::MAX_PARAS . '"'); break;
		case 'minsize'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_SIZE .'" max="' . kzFauxTexte::MAX_SIZE .'" step="' . kzFauxTexte::STEP_SIZE .'"'); break;
		case 'maxsize'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_SIZE .'" max="' . kzFauxTexte::MAX_SIZE .'" step="' . kzFauxTexte::STEP_SIZE .'"'); break;
		case 'articles'		: plxUtils::printInput($input, $value, 'number', '3-', false, false, false, 'min="' . kzFauxTexte::MIN_ARTS . '" max="' . kzFauxTexte::MAX_ARTS . '"'); break;
		case 'author'		: plxUtils::printSelect($input, $plxPlugin->getAuthors(), $value); break;
		case 'categorie'	: plxUtils::printSelect($input, $plxPlugin->getCategories(), $value); break;
		case 'medias'		: plxUtils::printSelect($input, $plxPlugin->getMedias(), $value); break;
		case 'template'		: plxUtils::printSelect($input, $plxPlugin->getTemplates(), $value); break;
		case 'begin'		: plxUtils::printInput($input, $value, 'date'); break;
		case 'thumb'		: plxUtils::printSelect($input, $yes_no, $value); break;
		case 'replace_all'	: plxUtils::printSelect($input, $yes_no, $value); break;
	}
	if(substr($input, -4) == 'size') {
?>
 <em><?php printf($plxPlugin->getLang('MIN_MAX_SIZE'), kzFauxTexte::STEP_SIZE, kzFauxTexte::MIN_SIZE, kzFauxTexte::MAX_SIZE); ?></em>
<?php
	}
?>
	</div>
<?php
}
?>
</form>
<div>
	<h3>Bibliothèques numériques :</h3>
	<ul>
		<li><a href="https://bibliothequenumerique.tv5monde.com/livres" target="_blank">TV5 Monde</a></li>
		<li><a href="https://ebooks-bnr.com/" target="_blank">Bibliothèque Numérique Romande</a></li>
		<li><a href="http://fr.feedbooks.com/publicdomain" target="_blank">FeedBooks</a></li>
		<li><a href="https://www.ebooksgratuits.com/ebooks.php" target="_blank">EbooksGratuit</a></li>
		<li><a href="http://www.efele.net/ebooks/i" target="_blank">Efele</a></li>
	</ul>
	<h3>Quelques livres recommandés :</h3>
	<ul>
		<li><a href="https://fr.feedbooks.com/book/55.epub" download>Le tour du Monde en 80 jours - Jules Verne</a></li>
		<li><a href="https://ebooks-bnr.com/ebooks/epub/pergaud_vie_betes_psycho_animale.epub" download>La vie des bêtes - Louis Pergaud</a></li>
		<li><a href="https://bibliothequenumerique.tv5monde.com/livre/201/Nana" download>Nana - Emile Zola</a></li>
	</ul>
</div>
<script>
(function() {
	document.getElementById('<?= $plugin ?>').addEventListener('submit', function(event) {
		if(parseInt(event.target.elements.minsize.value) >= parseInt(event.target.elements.maxsize.value)) {
			event.preventDefault();
			event.target.elements.minsize.focus();
			alert("<?= $plxPlugin->getLang('WARN_PARAGRAPH_LIMITS') ?>");
		} else {
			event.target.classList.add('spinner');
		}
	})
})();
</script>
